codeunit 50014 DynamicwebOrdersSubscriber
{
    EventSubscriberInstance = StaticAutomatic;

    var
        DynamicwebCustomHelper: Codeunit DynamicwebCustomHelper;

    [EventSubscriber(ObjectType::Codeunit, Codeunit::DynamicwebOrdersPublisher, 'OnBeforeExecutePutOrdersRequest', '', true, true)]
    procedure OnBeforeExecutePutOrdersRequest(var requestDoc: XmlDocument; var stopExecution: Boolean; var responseDoc: XmlDocument);
    begin
        DynamicwebCustomHelper.AddCustomElement('OnBeforeExecutePutOrdersRequest', responseDoc);
    end;

    [EventSubscriber(ObjectType::Codeunit, Codeunit::DynamicwebOrdersPublisher, 'OnAfterExecutePutOrdersRequest', '', true, true)]
    procedure OnAfterExecutePutOrdersRequest(var requestDoc: XmlDocument; var responseDoc: XmlDocument);
    begin
        DynamicwebCustomHelper.AddCustomElement('OnAfterExecutePutOrdersRequest', responseDoc);
    end;

    [EventSubscriber(ObjectType::Codeunit, Codeunit::DynamicwebOrdersPublisher, 'OnBeforeWriteNote', '', true, true)]
    procedure OnBeforeWriteNote(var noteText: Text; var skipWrittingNote: Boolean; salesHeader: Record "Sales Header");
    begin
        noteText := 'Custom note text';
    end;

    [EventSubscriber(ObjectType::Codeunit, Codeunit::DynamicwebOrdersPublisher, 'OnBeforeCalculateOrderRequest', '', true, true)]
    procedure OnBeforeCalculateOrderRequest(var orderNode: XmlNode; var stopExecution: Boolean; var responseRootNode: XmlNode);
    begin
        DynamicwebCustomHelper.AddCustomElement('OnBeforeCalculateOrderRequest', responseRootNode);
    end;

    [EventSubscriber(ObjectType::Codeunit, Codeunit::DynamicwebOrdersPublisher, 'OnAfterCalculateOrderRequest', '', true, true)]
    procedure OnAfterCalculateOrderRequest(var orderNode: XmlNode; var responseRootNode: XmlNode);
    begin
        DynamicwebCustomHelper.AddCustomElement('OnAfterCalculateOrderRequest', responseRootNode);
    end;

    [EventSubscriber(ObjectType::Codeunit, Codeunit::DynamicwebOrdersPublisher, 'OnBeforeCreateOrderRequest', '', true, true)]
    procedure OnBeforeCreateOrderRequest(var orderNode: XmlNode; var stopExecution: Boolean; var responseRootNode: XmlNode);
    begin
        DynamicwebCustomHelper.AddCustomElement('OnBeforeCreateOrderRequest', responseRootNode);
    end;


    [EventSubscriber(ObjectType::Codeunit, Codeunit::DynamicwebOrdersPublisher, 'OnAfterCreateOrderRequest', '', true, true)]
    procedure OnAfterCreateOrderRequest(var orderNode: XmlNode; var responseRootNode: XmlNode);
    begin
        DynamicwebCustomHelper.AddCustomElement('OnAfterCreateOrderRequest', responseRootNode);
    end;

    [EventSubscriber(ObjectType::Codeunit, Codeunit::DynamicwebOrdersPublisher, 'OnBeforeUpdateSalesHeader', '', true, true)]
    procedure OnBeforeUpdateSalesHeader(var salesheader: Record "Sales Header"; orderRequestNode: XmlNode);
    begin
        salesheader."Sell-to Address" := 'Hello from OnBeforeUpdateSalesHeader';
    end;

    [EventSubscriber(ObjectType::Codeunit, Codeunit::DynamicwebOrdersPublisher, 'OnBeforeCreateSalesLine', '', true, true)]
    procedure OnBeforeCreateSalesLine(var salesline: Record "Sales Line"; var salesheader: Record "Sales Header"; requestDoc: XmlDocument; var requestOrderNode: XmlNode; var requestOrderLineNode: XmlNode);
    begin
        salesline.Description := 'Hello from OnBeforeCreateSalesLine';
    end;

    [EventSubscriber(ObjectType::Codeunit, Codeunit::DynamicwebOrdersPublisher, 'OnBeforeAddSalesLineToResponse', '', true, true)]
    procedure OnBeforeAddSalesLineToResponse(var salesline: Record "Sales Line"; var salesheader: Record "Sales Header"; var dynamicwebDiscountId: Text; var dynamicwebDiscountName: Text; var cancelAdd: boolean);
    begin
        //Skip adding sales line with 1936-S product to response xml
        if (salesLine."No." = '1936-S') then
            cancelAdd := true;
    end;

    [EventSubscriber(ObjectType::Codeunit, Codeunit::DynamicwebOrdersPublisher, 'OnAfterAddSalesLineToResponse', '', true, true)]
    procedure OnAfterAddSalesLineToResponse(var responseOrderLineXml: XmlNode; salesline: Record "Sales Line"; salesheader: Record "Sales Header");
    begin
        DynamicwebCustomHelper.AddField(responseOrderLineXml, 'OnAfterAddSalesLineToResponse', 'hello');
    end;

    [EventSubscriber(ObjectType::Codeunit, Codeunit::DynamicwebOrdersPublisher, 'OnAfterAddBCOrderDiscountOrderLineToResponse', '', true, true)]
    procedure OnAfterAddBCOrderDiscountOrderLineToResponse(var responseOrderLineXml: XmlNode; salesheader: Record "Sales Header");
    begin
        DynamicwebCustomHelper.AddField(responseOrderLineXml, 'OnAfterAddBCOrderDiscountOrderLineToResponse', 'hello');
    end;

    [EventSubscriber(ObjectType::Codeunit, Codeunit::DynamicwebOrdersPublisher, 'OnBeforeInsertDynamicwebShippingSalesLine', '', true, true)]
    procedure OnBeforeInsertDynamicwebShippingSalesLine(var salesline: Record "Sales Line"; var cancelAdd: Boolean);
    begin
        salesline."Description" := 'Hello from OnBeforeInsertDynamicwebShippingSalesLine';
    end;

    [EventSubscriber(ObjectType::Codeunit, Codeunit::DynamicwebOrdersPublisher, 'OnAfterAddSalesHeaderToResponse', '', true, true)]
    procedure OnAfterAddSalesHeaderToResponse(var responseSalesHeaderXml: XmlNode; salesheader: Record "Sales Header");
    begin
        DynamicwebCustomHelper.AddField(responseSalesHeaderXml, 'OnAfterAddSalesHeaderToResponse', 'hello');
    end;
}